<?php

namespace Drupal\symfony_mailer_lite_microsoft\Plugin\SymfonyMailerLite\Transport;

use Drupal\Core\Form\FormStateInterface;
use Drupal\symfony_mailer_lite\Plugin\SymfonyMailerLite\Transport\TransportBase;

/**
 * Defines the Microsoft Mail Transport plug-in.
 *
 * @SymfonyMailerLiteTransport(
 *   id = "microsoft_graph_api",
 *   label = @Translation("Microsoft Graph API"),
 *   description = @Translation("Use Microsoft Graph API with OAuth 2.0 to send emails."),
 * )
 */
class MicrosoftTransport extends TransportBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'user' => '',
      'tenant' => '',
      'client_id' => '',
      'client_secret' => '',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state,
  ) {

    $form['user'] = [
      '#type' => 'textfield',
      '#title' => $this->t('User name / email (sender)'),
      '#default_value' => $this->configuration['user'],
      '#required' => TRUE,
      '#description' => $this->t('User name / email to log in.'),
    ];

    $form['tenant'] = [
      '#type' => 'textfield',
      '#title' => $this->t('TenantID'),
      '#required' => TRUE,
      '#default_value' => $this->configuration['tenant'],
    ];

    $form['client_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client ID'),
      '#required' => TRUE,
      '#default_value' => $this->configuration['client_id'],
    ];

    $form['client_secret'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Client Secret'),
      '#required' => TRUE,
      '#default_value' => $this->configuration['client_secret'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(
    array &$form,
    FormStateInterface $form_state,
  ) {
    $this->configuration['user'] = $form_state->getValue('user');
    $this->configuration['tenant'] = $form_state->getValue('tenant');
    $this->configuration['client_id'] = $form_state->getValue('client_id');
    $this->configuration['client_secret'] = $form_state->getValue('client_secret');
  }

  public function getDsn() {
    $cfg = $this->configuration;
    return sprintf(
      'microsoft-graph-api://%s:%s@%s?from=%s',
      $cfg['client_id'],
      $cfg['client_secret'],
      $cfg['tenant'],
      $cfg['user']
    );
  }

}
