<?php

namespace Drupal\symfony_mailer_lite_microsoft\Transport;

use Drupal\Core\Cache\CacheBackendInterface;
use Psr\EventDispatcher\EventDispatcherInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\Mailer\Exception\UnsupportedSchemeException;
use Symfony\Component\Mailer\Transport\AbstractTransportFactory;
use Symfony\Component\Mailer\Transport\Dsn;
use Symfony\Component\Mailer\Transport\TransportFactoryInterface;
use Symfony\Component\Mailer\Transport\TransportInterface;
use Symfony\Contracts\HttpClient\HttpClientInterface;

class GraphApiTransportFactory extends AbstractTransportFactory implements TransportFactoryInterface {

  private const EXPECTED_SCHEME = 'microsoft-graph-api';

  protected ?EventDispatcherInterface $dispatcher;

  protected ?HttpClientInterface $client;

  protected ?LoggerInterface $logger;

  public function __construct(
    protected CacheBackendInterface $cache,
    ?EventDispatcherInterface $dispatcher = NULL,
    ?HttpClientInterface $client = NULL,
    ?LoggerInterface $logger = NULL,
  ) {
    $this->dispatcher = $dispatcher;
    $this->client = $client;
    $this->logger = $logger;
    parent::__construct($dispatcher, $client, $logger);
  }

  public function create(Dsn $dsn): TransportInterface {
    $scheme = $dsn->getScheme();
    if ($scheme !== self::EXPECTED_SCHEME) {
      throw new UnsupportedSchemeException($dsn, 'Microsoft Office365 Graph API', $this->getSupportedSchemes());
    }

    $from = $dsn->getOption('from') ?? '';

    return new GraphApiTransport(
      $dsn->getHost(),
      $dsn->getUser(),
      $dsn->getPassword(),
      $from,
      $this->cache,
      $this->client,
      $this->dispatcher,
      $this->logger
    );
  }

  protected function getSupportedSchemes(): array {
    return [self::EXPECTED_SCHEME];
  }

}
